Available models
================

These are the model classes available.  Using :class:`Function` user-written
Python functions can be used as models too.

.. module:: ufit.models

Generic
-------

.. autoclass:: Function

Peaks
-----

.. autoclass:: Gauss

.. autoclass:: GaussInt

.. autoclass:: Lorentz

.. autoclass:: LorentzInt

.. autoclass:: Voigt

.. autoclass:: PseudoVoigt

.. autoclass:: DHO

Corrections
-----------

.. autoclass:: Background

.. autoclass:: SlopingBackground

.. autoclass:: CKI_Corr

.. autoclass:: Bose

Others
------

.. autoclass:: Const

.. autoclass:: StraightLine

.. autoclass:: Parabola

.. autoclass:: Cosine

.. autoclass:: Cosine2

.. autoclass:: Sinc

.. autoclass:: ExpDecay

.. autoclass:: PowerLaw

.. autoclass:: GaussianConvolution
